obelisk.asynchronous.consumer\_test
===================================

.. automodule:: obelisk.asynchronous.consumer_test

   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      test_demo_igent
   